==> aws-sdk-js-2.7.7.jar: META-INF/resources/webjars/aws-sdk-js/2.7.7/clients/all.d.ts <==
export import ACM = require('./acm');
export import APIGateway = require('./apigateway');
export import ApplicationAutoScaling = require('./applicationautoscaling');
export import AutoScaling = require('./autoscaling');
export import Budgets = require('./budgets');
export import CloudFormation = require('./cloudformation');
export import CloudFront = require('./cloudfront');
export import CloudHSM = require('./cloudhsm');
export import CloudSearch = require('./cloudsearch');
export import CloudSearchDomain = require('./cloudsearchdomain');
export import CloudTrail = require('./cloudtrail');
export import CloudWatch = require('./cloudwatch');
export import CloudWatchEvents = require('./cloudwatchevents');
export import CloudWatchLogs = require('./cloudwatchlogs');
export import CodeCommit = require('./codecommit');
export import CodeDeploy = require('./codedeploy');
export import CodePipeline = require('./codepipeline');
export import CognitoIdentity = require('./cognitoidentity');
export import CognitoIdentityServiceProvider = require('./cognitoidentityserviceprovider');
export import CognitoSync = require('./cognitosync');
export import ConfigService = require('./configservice');
export import DataPipeline = require('./datapipeline');
export import DeviceFarm = require('./devicefarm');
export import DirectConnect = require('./directconnect');
export import DirectoryService = require('./directoryservice');
export import Discovery = require('./discovery');
export import DMS = require('./dms');
export import DynamoDB = require('./dynamodb');
export import DynamoDBStreams = require('./dynamodbstreams');
export import EC2 = require('./ec2');
export import ECR = require('./ecr');
export import ECS = require('./ecs');
export import EFS = require('./efs');
export import ElastiCache = require('./elasticache');
export import ElasticBeanstalk = require('./elasticbeanstalk');
export import ELB = require('./elb');
export import ELBv2 = require('./elbv2');
export import EMR = require('./emr');
export import ES = require('./es');
export import ElasticTranscoder = require('./elastictranscoder');
export import Firehose = require('./firehose');
export import GameLift = require('./gamelift');
export import Glacier = require('./glacier');
export import IAM = require('./iam');
export import ImportExport = require('./importexport');
export import Inspector = require('./inspector');
export import Iot = require('./iot');
export import IotData = require('./iotdata');
export import Kinesis = require('./kinesis');
export import KinesisAnalytics = require('./kinesisanalytics');
export import KMS = require('./kms');
export import Lambda = require('./lambda');
export import MachineLearning = require('./machinelearning');
export import MarketplaceCommerceAnalytics = require('./marketplacecommerceanalytics');
export import MarketplaceMetering = require('./marketplacemetering');
export import MobileAnalytics = require('./mobileanalytics');
export import OpsWorks = require('./opsworks');
export import RDS = require('./rds');
export import Redshift = require('./redshift');
export import Route53 = require('./route53');
export import Route53Domains = require('./route53domains');
export import S3 = require('./s3');
export import ServiceCatalog = require('./servicecatalog');
export import SES = require('./ses');
export import SimpleDB = require('./simpledb');
export import SMS = require('./sms');
export import Snowball = require('./snowball');
export import SNS = require('./sns');
export import SQS = require('./sqs');
export import SSM = require('./ssm');
export import StorageGateway = require('./storagegateway');
export import STS = require('./sts');
export import Support = require('./support');
export import SWF = require('./swf');
export import WAF = require('./waf');
export import WorkSpaces = require('./workspaces');

==> aws-sdk-js-2.7.25.jar: META-INF/resources/webjars/aws-sdk-js/2.7.25/clients/all.d.ts <==
export import ACM = require('./acm');
export import APIGateway = require('./apigateway');
export import ApplicationAutoScaling = require('./applicationautoscaling');
export import AppStream = require('./appstream');
export import AutoScaling = require('./autoscaling');
export import Batch = require('./batch');
export import Budgets = require('./budgets');
export import CloudFormation = require('./cloudformation');
export import CloudFront = require('./cloudfront');
export import CloudHSM = require('./cloudhsm');
export import CloudSearch = require('./cloudsearch');
export import CloudSearchDomain = require('./cloudsearchdomain');
export import CloudTrail = require('./cloudtrail');
export import CloudWatch = require('./cloudwatch');
export import CloudWatchEvents = require('./cloudwatchevents');
export import CloudWatchLogs = require('./cloudwatchlogs');
export import CodeBuild = require('./codebuild');
export import CodeCommit = require('./codecommit');
export import CodeDeploy = require('./codedeploy');
export import CodePipeline = require('./codepipeline');
export import CognitoIdentity = require('./cognitoidentity');
export import CognitoIdentityServiceProvider = require('./cognitoidentityserviceprovider');
export import CognitoSync = require('./cognitosync');
export import ConfigService = require('./configservice');
export import CUR = require('./cur');
export import DataPipeline = require('./datapipeline');
export import DeviceFarm = require('./devicefarm');
export import DirectConnect = require('./directconnect');
export import DirectoryService = require('./directoryservice');
export import Discovery = require('./discovery');
export import DMS = require('./dms');
export import DynamoDB = require('./dynamodb');
export import DynamoDBStreams = require('./dynamodbstreams');
export import EC2 = require('./ec2');
export import ECR = require('./ecr');
export import ECS = require('./ecs');
export import EFS = require('./efs');
export import ElastiCache = require('./elasticache');
export import ElasticBeanstalk = require('./elasticbeanstalk');
export import ELB = require('./elb');
export import ELBv2 = require('./elbv2');
export import EMR = require('./emr');
export import ES = require('./es');
export import ElasticTranscoder = require('./elastictranscoder');
export import Firehose = require('./firehose');
export import GameLift = require('./gamelift');
export import Glacier = require('./glacier');
export import Health = require('./health');
export import IAM = require('./iam');
export import ImportExport = require('./importexport');
export import Inspector = require('./inspector');
export import Iot = require('./iot');
export import IotData = require('./iotdata');
export import Kinesis = require('./kinesis');
export import KinesisAnalytics = require('./kinesisanalytics');
export import KMS = require('./kms');
export import Lambda = require('./lambda');
export import Lightsail = require('./lightsail');
export import MachineLearning = require('./machinelearning');
export import MarketplaceCommerceAnalytics = require('./marketplacecommerceanalytics');
export import MarketplaceMetering = require('./marketplacemetering');
export import MobileAnalytics = require('./mobileanalytics');
export import OpsWorks = require('./opsworks');
export import OpsWorksCM = require('./opsworkscm');
export import Pinpoint = require('./pinpoint');
export import Polly = require('./polly');
export import RDS = require('./rds');
export import Redshift = require('./redshift');
export import Rekognition = require('./rekognition');
export import Route53 = require('./route53');
export import Route53Domains = require('./route53domains');
export import S3 = require('./s3');
export import ServiceCatalog = require('./servicecatalog');
export import SES = require('./ses');
export import Shield = require('./shield');
export import SimpleDB = require('./simpledb');
export import SMS = require('./sms');
export import Snowball = require('./snowball');
export import SNS = require('./sns');
export import SQS = require('./sqs');
export import SSM = require('./ssm');
export import StorageGateway = require('./storagegateway');
export import StepFunctions = require('./stepfunctions');
export import STS = require('./sts');
export import Support = require('./support');
export import SWF = require('./swf');
export import XRay = require('./xray');
export import WAF = require('./waf');
export import WAFRegional = require('./wafregional');
export import WorkSpaces = require('./workspaces');
